@@ -1,4 +1,5 @@
 import { defineMessages, injectIntl } from 'react-intl';
+import PropTypes from 'prop-types';
 import React from 'react';
 
 import DriverFields from './DriverFields';
@@ -37,7 +38,7 @@ class PXEAndDRACDriverFields extends React.Component {
 }
 
 PXEAndDRACDriverFields.propTypes = {
-  intl: React.PropTypes.object
+  intl: PropTypes.object
 };
 
 export default injectIntl(PXEAndDRACDriverFields);
