@@ -6,45 +6,51 @@ import { getRole } from './roles';
 import { getEnvironment } from './environmentConfiguration';
 import { Resource } from '../immutableRecords/parameters';
 
-const parameters = (state) => state.parameters.get('parameters');
-const resources = (state) => state.parameters.get('resources');
-const resourceById = (state, resourceId) => state.parameters.resources.get(resourceId);
+const parameters = state => state.parameters.get('parameters');
+const resources = state => state.parameters.get('resources');
+const resourceById = (state, resourceId) =>
+  state.parameters.resources.get(resourceId);
 
-export const getParameters = createSelector(
-  [parameters], parameters =>
-    parameters.sortBy(p => p.name.toLowerCase())
+export const getParameters = createSelector([parameters], parameters =>
+  parameters.sortBy(p => p.name.toLowerCase())
 );
 
-export const getResources = createSelector(
-  [resources], resources =>
-    resources.sortBy(r => r.type)
+export const getResources = createSelector([resources], resources =>
+  resources.sortBy(r => r.type)
 );
 
 /**
  * Returns parameters excluding internal parameters
  */
 export const getParametersExclInternal = createSelector(
-  [getParameters], parameters =>
-    parameters.filterNot(p => internalParameters.includes(p.name))
+  [getParameters],
+  parameters => parameters.filterNot(p => internalParameters.includes(p.name))
 );
 
 /**
  * Returns parameters defined in root template (overcloud.yaml)
  */
 export const getRootParameters = createSelector(
-  [getResources, getParameters], (resources, parameters) =>
+  [getResources, getParameters],
+  (resources, parameters) =>
     resources
       .find(resource => resource.name === 'Root', null, new Resource())
       .parameters.update(filterParameters(parameters))
 );
 
 export const getRoleResource = createSelector(
-  [getResources, getRole], (resources, role) =>
-    resources.find(resource => resource.type === `OS::TripleO::${role.name}`, null, new Resource())
+  [getResources, getRole],
+  (resources, role) =>
+    resources.find(
+      resource => resource.type === `OS::TripleO::${role.name}`,
+      null,
+      new Resource()
+    )
 );
 
 export const getRoleParameters = createSelector(
-  [getResources, getParameters, getRoleResource], (resources, parameters, roleResource) =>
+  [getResources, getParameters, getRoleResource],
+  (resources, parameters, roleResource) =>
     roleResource.parameters.update(filterParameters(parameters))
 );
 
@@ -52,10 +58,15 @@ export const getRoleParameters = createSelector(
  * Returns map of Service resources for specific Role including map of parameters for each Service
  */
 export const getRoleServices = createSelector(
-  [getResources, getParametersExclInternal, getRole], (resources, parameters, role) =>
+  [getResources, getParametersExclInternal, getRole],
+  (resources, parameters, role) =>
     resources
       // traverse the resources to find Role's ServiceChain resource
-      .find(resource => resource.name === `${role.name}ServiceChain`, null, new Resource())
+      .find(
+        resource => resource.name === `${role.name}ServiceChain`,
+        null,
+        new Resource()
+      )
       .get('nestedParameters', List())
       .map(r => resources.get(r))
       .find(r => r.name === 'ServiceChain', null, new Resource())
@@ -64,11 +75,20 @@ export const getRoleServices = createSelector(
       // replace list of resource ids with Map of actual resources - Services
       .update(filterResources(resources))
       // for each Service, update it's parameters to include parameters of it's nested resources
-      .map(r => r
-        .update(resource => resource
-          .set('parameters',
-               _extractParameters(resource.parameters, resource.nestedParameters, resources)))
-        .update('parameters', filterParameters(parameters)))
+      .map(r =>
+        r
+          .update(resource =>
+            resource.set(
+              'parameters',
+              _extractParameters(
+                resource.parameters,
+                resource.nestedParameters,
+                resources
+              )
+            )
+          )
+          .update('parameters', filterParameters(parameters))
+      )
 );
 
 /**
@@ -79,26 +99,40 @@ export const getRoleNetworkConfig = createSelector(
   (resources, parameters, roleResource, role) =>
     roleResource.nestedParameters
       .map(r => resources.get(r))
-      .find(resource => resource.type === `OS::TripleO::${role.name}::Net::SoftwareConfig`,
-            null,
-            new Resource())
+      .find(
+        resource =>
+          resource.type === `OS::TripleO::${role.name}::Net::SoftwareConfig`,
+        null,
+        new Resource()
+      )
       .update('parameters', filterParameters(parameters))
 );
 
-
 export const getEnvironmentParameters = createSelector(
   [getParametersExclInternal, getResources, getEnvironment],
   (parameters, resources, environment) => {
-    return resources
+    return (
+      resources
         // get list of resources from environment resource_registry
         .filter(r => environment.resourceRegistry.keySeq().includes(r.type))
         // collect parameter names from those resources
-        .reduce((result, resource) => result.union(resource.parameters), Set())
+        .reduce(
+          (result, resource) =>
+            result.union(
+              _extractParameters(
+                resource.parameters,
+                resource.nestedParameters,
+                resources
+              )
+            ),
+          Set()
+        )
         // add parameters from environment's 'parameters' section to the list
         .union(environment.parameterDefaults.keySeq())
         .toMap()
         // convert list of parameter names to map of actual parameter records
-        .update(filterParameters(parameters));
+        .update(filterParameters(parameters))
+    );
   }
 );
 
@@ -107,7 +141,8 @@ export const getEnvironmentParameters = createSelector(
  * (Can be used e.g. to fetch parameters for a service)
  */
 export const getResourceParameters = createSelector(
-  [getParameters, resourceById], (parameters, resource) =>
+  [getParameters, resourceById],
+  (parameters, resource) =>
     resource.parameters.update(filterParameters(parameters))
 );
 
@@ -116,25 +151,29 @@ export const getResourceParameters = createSelector(
  * @param resources - Map of resources to filter on
  * @returns function
  */
-const filterResources = (resources) =>
-  resourceUUIDs => resources.filter((p, k) => resourceUUIDs.includes(k));
+const filterResources = resources => resourceUUIDs =>
+  resources.filter((p, k) => resourceUUIDs.includes(k));
 
 /**
  * Helper function to convert list of parameter names into map of actual parameters
  * @param parameters - Map of parameters to filter on
  * @returns function
  */
-const filterParameters = (parameters) =>
-  parameterNames => parameters.filter((p, k) => parameterNames.includes(k));
+const filterParameters = parameters => parameterNames =>
+  parameters.filter((p, k) => parameterNames.includes(k));
 
 /**
  * Get Parameter list for resource by Id including parameters from all nested resources
  * (Can be used e.g. to fetch parameters for a service)
  */
 export const getResourceParametersDeep = createSelector(
-  [getResources, getParameters, resourceById], (resources, parameters, resource) =>
-    _extractParameters(resource.parameters, resource.nestedParameters, resources)
-      .update(filterParameters(parameters))
+  [getResources, getParameters, resourceById],
+  (resources, parameters, resource) =>
+    _extractParameters(
+      resource.parameters,
+      resource.nestedParameters,
+      resources
+    ).update(filterParameters(parameters))
 );
 
 /**
@@ -143,8 +182,10 @@ export const getResourceParametersDeep = createSelector(
 const _extractParameters = (parameters, nestedResources, allResources) => {
   return nestedResources.reduce((pars, res) => {
     const resource = allResources.get(res);
-    return _extractParameters(pars.toSet().union(resource.parameters.toSet()).toList(),
-                              resource.nestedParameters,
-                              allResources);
+    return _extractParameters(
+      pars.toSet().union(resource.parameters.toSet()).toList(),
+      resource.nestedParameters,
+      allResources
+    );
   }, parameters);
 };
